Location Choices — Hadrian 1.0 documentation

### Navigation

- index
- next |
- previous |
- Hadrian 1.0 documentation »

# Location Choices

hadrian.choices.locations contains several helper tuples for using in django choice fields.

## Countries

Contains a list of countries using the international standard.

Usage:

    from hadrian.choices.locations import COUNTRY_CHOICES

### Navigation

- index
- next |
- previous |
- Hadrian 1.0 documentation »